@@ -7,8 +7,6 @@
 #undef HAVE_LIBSM
 #undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
 #undef HAVE_PROGRAM_INVOCATION_NAME
-#undef PACKAGE
-#undef VERSION
 
 #undef HAVE_ESD
 #undef HAVE_LIBESD
@@ -46,3 +44,6 @@
 #undef HAVE_HOSTS_ACCESS
 
 #undef HAVE_LIBBZ2
+
+#undef GNOME_ICONDIR
+
