@@ -110,6 +110,15 @@ static gboolean		send_client_message_3L	  (Window     recipient,
 						   glong      long1,
 						   glong      long2,
 						   glong      long3);
+static gboolean		send_client_message_5L	  (Window     recipient,
+						   Window     event_window,
+						   Atom       message_type,
+						   long       event_mask,
+						   glong      long1,
+						   glong      long2,
+						   glong      long3,
+						   glong      long4,
+						   glong      long5);
 static void 		get_task_root_and_frame   (GwmhTask    *task);
 static GdkWindow*	gdk_window_ref_from_xid	  (Window       xwin);
 static guint            gwmh_property_atom2info   (Atom         atom,
@@ -132,6 +141,7 @@ static gboolean		client_list_sync	  (guint32           *xwindows_ids,
 static GdkFilterReturn	task_event_monitor	  (GdkXEvent         *gdk_xevent,
 						   GdkEvent          *event,
 						   gpointer           task_pointer);
+static GdkFilterReturn	task_event_monitor_frame_wrapper (GdkXEvent*, GdkEvent*, gpointer);
 static GdkFilterReturn	root_event_monitor	  (GdkXEvent         *gdk_xevent,
 						   GdkEvent          *event,
 						   gpointer           gdk_root);
@@ -508,7 +518,7 @@ send_client_message_2L (Window recipient,
 			glong  long1,
 			glong  long2)
 {
-  return send_client_message_3L (recipient, event_window, message_type, event_mask, long1, long2, 0);
+  return send_client_message_5L (recipient, event_window, message_type, event_mask, long1, long2, 0, 0, 0);
 }
 
 static gboolean
@@ -519,6 +529,20 @@ send_client_message_3L (Window recipient,
 			glong  long1,
 			glong  long2,
 			glong  long3)
+{
+  return send_client_message_5L (recipient, event_window, message_type, event_mask, long1, long2, long3, 0, 0);
+}
+
+static gboolean
+send_client_message_5L (Window recipient,
+			Window event_window,
+			Atom   message_type,
+			long   event_mask,
+			glong  long1,
+			glong  long2,
+			glong  long3,
+			glong  long4,
+			glong  long5)
 {
   XEvent xevent = { 0, };
 
@@ -531,6 +555,8 @@ send_client_message_3L (Window recipient,
   xevent.xclient.data.l[0] = long1;
   xevent.xclient.data.l[1] = long2;
   xevent.xclient.data.l[2] = long3;
+  xevent.xclient.data.l[3] = long4;
+  xevent.xclient.data.l[4] = long5;
 
   gdk_error_trap_push ();
 
@@ -645,19 +671,21 @@ get_task_root_and_frame (GwmhTask *task)
     {
       if (task->gdkframe)
 	{
-	  gdk_window_remove_filter (task->gdkframe, task_event_monitor, task);
+	  gdk_window_remove_filter (task->gdkframe, task_event_monitor_frame_wrapper, task);
 	  gdk_window_unref (task->gdkframe);
 	  task->gdkframe = NULL;
 	}
 
+      task->xframe = xframe;
       if (xframe)
 	{
 	  XWindowAttributes attribs = { 0, };
 
-	  task->xframe = xframe;
 	  task->gdkframe = gdk_window_ref_from_xid (task->xframe);
 
-	  gdk_window_add_filter (task->gdkframe, task_event_monitor, task);
+	  { int nf = g_list_length (((GdkWindowPrivate*) task->gdkframe)->filters);
+	  gdk_window_add_filter (task->gdkframe, task_event_monitor_frame_wrapper, task);
+	  g_assert (g_list_length (((GdkWindowPrivate*) task->gdkframe)->filters) == nf + 1); }
 	  /* select events */
 	  gdk_error_trap_push ();
 	  XGetWindowAttributes (GDK_DISPLAY (),
@@ -714,6 +742,14 @@ root_event_monitor (GdkXEvent *gdk_xevent,
   return GDK_FILTER_CONTINUE;
 }
 
+static GdkFilterReturn
+task_event_monitor_frame_wrapper (GdkXEvent *gdk_xevent,
+				  GdkEvent  *event,
+				  gpointer   task_pointer)
+{
+  return task_event_monitor (gdk_xevent, event, task_pointer);
+}
+
 static GdkFilterReturn
 task_event_monitor (GdkXEvent *gdk_xevent,
 		    GdkEvent  *event,
@@ -746,24 +782,10 @@ task_event_monitor (GdkXEvent *gdk_xevent,
 	}
       /* gwmh_task_queue_update (task, GWMH_TASK_INFO_GEOMETRY); */
       break;
-    case FocusIn:
-      if (!GWMH_TASK_FOCUSED (task))
-	{
-	  task->focused = TRUE;
-	  ichanges |= GWMH_TASK_INFO_FOCUSED;
-	}
-      /* gwmh_task_queue_update (task, GWMH_TASK_INFO_FOCUSED); */
-      break;
-    case FocusOut:
-      if (GWMH_TASK_FOCUSED (task))
-	{
-	  task->focused = FALSE;
-	  ichanges |= GWMH_TASK_INFO_FOCUSED;
-	}
-      /* gwmh_task_queue_update (task, GWMH_TASK_INFO_FOCUSED); */
-      break;
     case PropertyNotify:
       imask = gwmh_property_atom2info (xevent->xproperty.atom, TRUE);
+      if (xevent->xproperty.atom == XA_WM_HINTS)
+	      ichanges |= GWMH_TASK_INFO_WM_HINTS;
       break;
     case ReparentNotify:
       /* refetch frame and root window */
@@ -778,6 +800,29 @@ task_event_monitor (GdkXEvent *gdk_xevent,
 	  imask = GWMH_TASK_INFO_ALL;
 	  gwmh_desk_queue_update (GWMH_DESK_INFO_CLIENT_LIST);
 	}
+      if (GWMH_TASK_FOCUSED (task) && (xevent->type == UnmapNotify ||
+				       xevent->type == DestroyNotify))
+	{
+	  task->focused = FALSE;
+	  ichanges |= GWMH_TASK_INFO_FOCUSED;
+	}
+      break;
+    case FocusOut:
+      if (GWMH_TASK_FOCUSED (task) && (xevent->xfocus.detail != NotifyPointer &&
+				       xevent->xfocus.detail != NotifyInferior))
+	{
+	  task->focused = FALSE;
+	  ichanges |= GWMH_TASK_INFO_FOCUSED;
+	}
+      /* gwmh_task_queue_update (task, GWMH_TASK_INFO_FOCUSED); */
+      break;
+    case FocusIn:
+      if (!GWMH_TASK_FOCUSED (task))
+	{
+	  task->focused = TRUE;
+	  ichanges |= GWMH_TASK_INFO_FOCUSED;
+	}
+      /* gwmh_task_queue_update (task, GWMH_TASK_INFO_FOCUSED); */
       break;
     default:
       break;
@@ -797,6 +842,7 @@ gwmh_property_atom2info (Atom     atom,
 			 gboolean per_task)
 {
   static const Atom gwmh_XA_WM_NAME = XA_WM_NAME;
+  static const Atom gwmh_XA_WM_HINTS = XA_WM_HINTS;
   static const struct {
     const Atom *atom_p;
     guint       iflag;
@@ -818,15 +864,18 @@ gwmh_property_atom2info (Atom     atom,
     { &GWMHA_WIN_AREA,			GWMH_TASK_INFO_AREA, },
     { &GWMHA_WIN_WORKSPACE,		GWMH_TASK_INFO_DESKTOP, },
     { &XA_WM_STATE,			GWMH_TASK_INFO_ICONIFIED, },
+    { &gwmh_XA_WM_HINTS,                GWMH_TASK_INFO_WM_HINTS, },
     { &gwmh_XA_WM_NAME,			GWMH_TASK_INFO_MISC, },
   };
   guint i;
-
+  static int j = 0;
+  
   if (per_task)
     {
-      for (i = 0; i < sizeof (task_atom_masks) / sizeof (task_atom_masks[0]); i++)
-	if (*task_atom_masks[i].atom_p == atom)
+      for (i = 0; i < sizeof (task_atom_masks) / sizeof (task_atom_masks[0]); i++) 
+	if (*task_atom_masks[i].atom_p == atom) {
 	  return task_atom_masks[i].iflag;
+	}
     }
   else
     {
@@ -1645,7 +1694,9 @@ task_new (GdkWindow *window)
   task->xwin = GDK_WINDOW_XWINDOW (window);
   
   /* monitor events on the GdkWindow */
+  { int nf = g_list_length (((GdkWindowPrivate*) task->gdkwindow)->filters);
   gdk_window_add_filter (task->gdkwindow, task_event_monitor, task);
+  g_assert (g_list_length (((GdkWindowPrivate*) task->gdkwindow)->filters) == nf + 1); }
   /* select events */
   gdk_error_trap_push ();
   XGetWindowAttributes (GDK_DISPLAY (), task->xwin, &attribs);
@@ -1720,7 +1771,7 @@ task_delete (GwmhTask *task)
   gdk_window_unref (task->gdkwindow);
   if (task->gdkframe)
     {
-      gdk_window_remove_filter (task->gdkframe, task_event_monitor, task);
+      gdk_window_remove_filter (task->gdkframe, task_event_monitor_frame_wrapper, task);
       gdk_window_unref (task->gdkframe);
     }
   if (task->sroot)
@@ -2175,10 +2226,9 @@ gwmh_task_set_area (GwmhTask *task,
        harea == task->harea &&
        varea == task->varea))
     return;
-
+  
   gwmh_sync ();
-  gwmh_freeze_syncs ();
-
+  
   /* ugly hack for buggy window managers
    * that violate the spec and expect us to modify properties directly
    */
@@ -2192,16 +2242,17 @@ gwmh_task_set_area (GwmhTask *task,
       if (desktop != task->desktop)
 	XChangeProperty (GDK_DISPLAY (), task->xwin, GWMHA_WIN_WORKSPACE,
 			 XA_CARDINAL, 32, PropModeReplace, (unsigned char*) data, 1);
-
+      
       data[0] = harea;
       data[1] = varea;
       XChangeProperty (GDK_DISPLAY (), task->xwin, GWMHA_WIN_AREA,
 		       XA_CARDINAL, 32, PropModeReplace, (unsigned char*) data, 2);
-
+      
       gdk_error_trap_pop ();
     }
   else
     {
+      gwmh_freeze_syncs ();
       if (desktop != task->desktop)
 	send_client_message_2L (GDK_ROOT_WINDOW (), task->xwin,
 				GWMHA_WIN_WORKSPACE,
@@ -2211,9 +2262,8 @@ gwmh_task_set_area (GwmhTask *task,
 			      GWMHA_WIN_AREA,
 			      SubstructureNotifyMask,
 			      harea, varea, CurrentTime);
+      gwmh_thaw_syncs ();
     }
-  
-  gwmh_thaw_syncs ();
 }
 
 void
@@ -2255,6 +2305,26 @@ gwmh_desk_get_config (void)
   return &gwmh_desk;
 }
 
+void
+gwmh_window_send_client_message (GdkWindow *window,
+				 gulong     atom,
+				 gulong	    long1,
+				 gulong	    long2,
+				 gulong	    long3,
+				 gulong	    long4,
+				 gulong	    long5)
+{
+  g_return_if_fail (window != NULL);
+  g_return_if_fail (atom > 0);
+
+  if (!GDK_WINDOW_IS_DESTROYED (window))
+    send_client_message_5L (GDK_ROOT_WINDOW (),
+			    GDK_WINDOW_XWINDOW (window),
+			    atom,
+			    SubstructureNotifyMask,
+			    long1, long2, long3, long4, long5);
+}
+
 void
 gwmh_desk_guess_desktop_area (guint  desktop,
 			      guint *harea,
