@@ -9,6 +9,8 @@
 #include <gnome.h>
 #include <applet-widget.h>
 
+#include <libgnomeui/gnome-window-icon.h>
+
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <libart_lgpl/art_alphagamma.h>
 #include <libart_lgpl/art_filterlevel.h>
@@ -19,6 +21,10 @@
 #include <libart_lgpl/art_rgb_affine.h>
 #include <libart_lgpl/art_rgb_rgba_affine.h>
 
+/* The place where we will guess where we are */
+#define TIMEZONESPEC "/etc/timezone"
+int fools_day=1, fools_month=3;
+
 typedef struct _FishProp FishProp;
 struct _FishProp {
 	char *name;
@@ -196,6 +202,37 @@ static void
 load_properties(Fish *fish)
 {
 	char buf[256];
+	/* I think theese is a good place to guess where we are */
+	FILE *zone;
+	
+	zone = fopen(TIMEZONESPEC, "r");
+	if (zone != NULL) { /* If file doesn't exists we will stick to
+			       "Standard" fools day */
+		int i;
+		gboolean found = FALSE;
+		char *spanish_timezones[] = {
+			"Europe/Madrid",
+			"Africa/Ceuta",
+			"Atlantic/Canary",
+			"America/Mexico_City",
+			"Mexico/BajaSur",
+			"Mexico/BajaNorte",
+			"Mexico/General",
+			NULL
+		};
+		fscanf(zone, "%255s", buf);
+		fclose(zone);
+		for(i=0; !found && spanish_timezones[i]; i++) {
+			if (!strcmp(spanish_timezones[i], buf)) {
+				/* Hah!, We are in Spain or Mexico */
+				/* Spanish fool's day: 28th December*/
+				fools_day = 28;
+				fools_month = 11;
+				found = TRUE;
+			}
+		}
+	}
+
 	if(!defaults.image)
 		defaults.image = gnome_unconditional_pixmap_file ("fish/fishanim.png");
 
@@ -269,14 +306,14 @@ fish_timeout(gpointer data)
 	tm = localtime(&ourtime);
 
 	if(fish->april_fools) {
-		if(tm->tm_mon != 3 || tm->tm_mday != 1) {
+		if(tm->tm_mon != fools_month || tm->tm_mday != fools_day) {
 			fish->april_fools = FALSE;
 			load_image_file(fish);
 			setup_size(fish);
 			fish_timeout(fish);
 		}
 	} else {
-		if(tm->tm_mon == 3 && tm->tm_mday == 1) {
+		if(tm->tm_mon == fools_month && tm->tm_mday == fools_day) {
 			fish->april_fools = TRUE;
 			load_image_file(fish);
 			setup_size(fish);
@@ -285,6 +322,7 @@ fish_timeout(gpointer data)
 	}
 
 	/* on april fools, the fish id dead! */
+	/* on "Santos Inocentes" (spanish fool's day) the fish is dead */
 	if(!fish->april_fools) {
 		fish->curpix++;
 		if(fish->curpix>=fish->prop.frames) fish->curpix=0;
@@ -386,6 +424,8 @@ properties_dialog(AppletWidget *aw, gpointer data)
 	fish->pb = gnome_property_box_new();
 
 	gtk_window_set_title(GTK_WINDOW(fish->pb), _("GNOME Fish Properties"));
+	gnome_window_icon_set_from_file (GTK_WINDOW (fish->pb),
+					 GNOME_ICONDIR"/gnome-fish.png");
 
 	vbox = gtk_vbox_new(FALSE, GNOME_PAD);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), GNOME_PAD);
@@ -484,6 +524,8 @@ update_fortune_dialog(Fish *fish)
 				       TRUE);
 		gnome_dialog_close_hides(GNOME_DIALOG(fish->fortune_dialog),
 					 TRUE);
+		gnome_window_icon_set_from_file (GTK_WINDOW (fish->fortune_dialog),
+						 GNOME_ICONDIR"/gnome-fish.png");
 
 		fish->fortune_less = gnome_less_new();
 		fish->fortune_label = gtk_label_new("");
@@ -649,7 +691,9 @@ about_cb (AppletWidget *widget, gpointer data)
 				   "If anyone is found using this applet, he "
 				   "should be promptly sent for a psychiatric "
 				   "evaluation."),
-				 NULL);
+				 GNOME_ICONDIR"/gnome-fish.png");
+	gnome_window_icon_set_from_file (GTK_WINDOW (fish->aboutbox),
+					 GNOME_ICONDIR"/gnome-fish.png");
 	gtk_signal_connect(GTK_OBJECT(fish->aboutbox),"destroy",
 			   GTK_SIGNAL_FUNC(gtk_widget_destroyed), &fish->aboutbox);
 	gtk_widget_show (fish->aboutbox);
