@@ -18,6 +18,7 @@
 #include <config.h>
 #include <gnome.h>
 #include <applet-widget.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include "popcheck.h"
@@ -328,8 +329,19 @@ mailcheck_load_animation (MailCheck *mc, char *fname)
 	pbwidth = gdk_pixbuf_get_width(pb);
 	pbheight = gdk_pixbuf_get_height(pb);
 
-	height = mc->size;
-	width = pbwidth*((double)height/pbheight);
+	if(pbheight != mc->size) {
+		GdkPixbuf *pbt;
+		height = mc->size;
+		width = pbwidth*((double)height/pbheight);
+
+		pbt = gdk_pixbuf_scale_simple(pb, width, height,
+					      GDK_INTERP_NEAREST);
+		gdk_pixbuf_unref(pb);
+		pb = pbt;
+	} else {
+		width = pbwidth;
+		height = pbheight;
+	}
 
 	/* yeah, they have to be square, in case you were wondering :-) */
 	mc->frames = width / height;
@@ -339,7 +351,6 @@ mailcheck_load_animation (MailCheck *mc, char *fname)
 		mc->report_mail_mode = REPORT_MAIL_USE_BITMAP;
 	mc->nframe = 0;
 
-
 	gdk_pixbuf_render_pixmap_and_mask(pb,
 					  &mc->email_pixmap,
 					  &mc->email_mask,
@@ -1123,6 +1134,8 @@ mailcheck_properties (AppletWidget *applet, gpointer data)
 	mc->property_window = gnome_property_box_new ();
 	gtk_window_set_title (GTK_WINDOW (mc->property_window),
 			      _("Mail check properties"));
+	gnome_window_icon_set_from_file (GTK_WINDOW (mc->property_window),
+					 GNOME_ICONDIR"/gnome-mailcheck.png");
 
 	p = mailcheck_properties_page (mc);
 	gnome_property_box_append_page (GNOME_PROPERTY_BOX(mc->property_window),
@@ -1206,6 +1219,8 @@ mailcheck_about(AppletWidget *a_widget, gpointer a_data)
 				      authors,
 				      _("Mail check notifies you when new mail is on your mailbox"),
 				      NULL);
+	gnome_window_icon_set_from_file (GTK_WINDOW (mc->about),
+					 GNOME_ICONDIR"/gnome-mailcheck.png");
 	gtk_signal_connect( GTK_OBJECT(mc->about), "destroy",
 			    GTK_SIGNAL_FUNC(gtk_widget_destroyed), &mc->about );
 	gtk_widget_show(mc->about);
