@@ -1,5 +1,6 @@
 #include <config.h>
 #include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 
 #include "gstc.h"
 #include "gwmh.h"
@@ -14,7 +15,7 @@ static void cb_properties (void);
 static void cb_about (void);
 gchar *fixup_task_label (TasklistTask *task);
 gboolean is_task_visible (TasklistTask *task);
-void draw_task (TasklistTask *task);
+void draw_task (TasklistTask *task, GdkRectangle *rect);
 TasklistTask *find_gwmh_task (GwmhTask *gwmh_task);
 gboolean desk_notifier (gpointer func_data, GwmhDesk *desk, GwmhDeskInfoMask change_mask);
 gboolean task_notifier (gpointer func_data, GwmhTask *gwmh_task, GwmhTaskNotifyType ntype, GwmhTaskInfoMask imask);
@@ -208,7 +209,7 @@ is_task_visible (TasklistTask *task)
 
 /* Draw a single task */
 void
-draw_task (TasklistTask *task)
+draw_task (TasklistTask *task, GdkRectangle *rect)
 {
 	gchar *tempstr;
 	gint text_height, text_width;
@@ -225,7 +226,7 @@ draw_task (TasklistTask *task)
 		       GTK_STATE_ACTIVE : GTK_STATE_NORMAL,
 		       GWMH_TASK_FOCUSED (task->gwmh_task) ?
 		       GTK_SHADOW_IN : GTK_SHADOW_OUT,
-		       NULL, area, "button",
+		       rect, area, "button",
 		       task->x, task->y,
 		       task->width, task->height);
 
@@ -239,7 +240,7 @@ draw_task (TasklistTask *task)
 				 area->style->fg_gc[GTK_STATE_ACTIVE] :
 				 area->style->fg_gc[GTK_STATE_NORMAL],
 				 task->x +
-				 (Config.show_mini_icons ? 8 : 0) +
+				 (Config.show_mini_icons ? 10 : 0) +
 				 ((task->width - text_width) / 2),
 				 task->y + ((task->height - text_height) / 2) + text_height,
 				 tempstr);
@@ -255,11 +256,6 @@ draw_task (TasklistTask *task)
 		else
 			pixbuf = icon->normal;
 
-/*		gdk_gc_set_clip_mask (area->style->black_gc, icon->mask);
-		gdk_gc_set_clip_origin (area->style->black_gc,
-					task->x + 3 + (16 - gdk_pixbuf_get_width (pixbuf)) / 2,
-					task->y + (task->height - gdk_pixbuf_get_height (pixbuf)) / 2);*/
-
 		gdk_pixbuf_render_to_drawable_alpha (pixbuf,
 						     area->window,
 						     0, 0,
@@ -323,22 +319,22 @@ layout_tasklist (void)
 		}
 		
 		if (Config.horz_fixed) {
-			curheight = (ROW_HEIGHT * get_horz_rows() - 4) / num_rows;
-			curwidth = (Config.horz_width - 4) / num_cols;
+			curheight = (ROW_HEIGHT * get_horz_rows() - 0) / num_rows;
+			curwidth = (Config.horz_width - 0) / num_cols;
 
 		} else {
-			curheight = (ROW_HEIGHT * get_horz_rows() - 4) / num_rows;
+			curheight = (ROW_HEIGHT * get_horz_rows() - 0) / num_rows;
 			curwidth = Config.horz_taskwidth;
 
 			/* If the total width is higher than allowed, 
 			   we use the "fixed" way instead */
 			if ((curwidth * num_cols) > Config.horz_width)
-				curwidth = (Config.horz_width - 4) / num_cols;
+				curwidth = (Config.horz_width - 0) / num_cols;
 		}
 
 
-		curx = 2;
-		cury = 2;
+		curx = 0;
+		cury = 0;
 
 
 		while (temp_tasks) {
@@ -355,7 +351,7 @@ layout_tasklist (void)
 				if (curx >= Config.horz_width ||
 				    curx + curwidth > Config.horz_width) {
 					cury += curheight;
-					curx = 2;
+					curx = 0;
 				}
 			} else {
 
@@ -363,7 +359,7 @@ layout_tasklist (void)
 
 				if (curx >= num_cols * curwidth) {
 					cury += curheight;
-					curx = 2;
+					curx = 0;
 				}
 			}
 			
@@ -400,15 +396,15 @@ layout_tasklist (void)
 
 		curheight = ROW_HEIGHT;
 		if (Config.follow_panel_size)
-			curwidth = panel_size - 4;
+			curwidth = panel_size - 0;
 		else
-			curwidth = Config.vert_width - 4;
+			curwidth = Config.vert_width - 0;
 		
 		num_cols = 1;
 		num_rows = num;
 		
-		curx = 2;
-		cury = 2;
+		curx = 0;
+		cury = 0;
 
 		if (Config.vert_fixed)
 			vert_height = Config.vert_height;
@@ -429,9 +425,9 @@ layout_tasklist (void)
 
 			if (curx >= (Config.follow_panel_size?
 				     panel_size:
-				     Config.vert_width) - 4) {
+				     Config.vert_width) - 0) {
 				cury += curheight;
-				curx = 2;
+				curx = 0;
 			}
 			
 			if (temp_tasks->next)
@@ -492,14 +488,22 @@ task_notifier (gpointer func_data, GwmhTask *gwmh_task,
 	switch (ntype)
 	{
 	case GWMH_NOTIFY_INFO_CHANGED:
+		if (imask & GWMH_TASK_INFO_WM_HINTS) {
+			if (tasklist_icon_get_pixmap (find_gwmh_task (gwmh_task)) !=
+			    find_gwmh_task (gwmh_task)->wmhints_icon) {
+				tasklist_icon_destroy (find_gwmh_task (gwmh_task));
+				tasklist_icon_set (find_gwmh_task (gwmh_task));
+				draw_task (find_gwmh_task (gwmh_task), NULL);
+			}
+		}
 		if (imask & GWMH_TASK_INFO_GSTATE)
 			layout_tasklist ();
 		if (imask & GWMH_TASK_INFO_ICONIFIED)
 			layout_tasklist ();
 		if (imask & GWMH_TASK_INFO_FOCUSED)
-			draw_task (find_gwmh_task (gwmh_task));
+			draw_task (find_gwmh_task (gwmh_task), NULL);
 		if (imask & GWMH_TASK_INFO_MISC)
-			draw_task (find_gwmh_task (gwmh_task));
+			draw_task (find_gwmh_task (gwmh_task), NULL);
 		if (imask & GWMH_TASK_INFO_DESKTOP) {
 			if (Config.all_desks_minimized && 
 			    Config.all_desks_normal)
@@ -512,6 +516,7 @@ task_notifier (gpointer func_data, GwmhTask *gwmh_task,
 	case GWMH_NOTIFY_NEW:
 		task = g_malloc0 (sizeof (TasklistTask));
 		task->gwmh_task = gwmh_task;
+		task->wmhints_icon = tasklist_icon_get_pixmap (task);
 		tasklist_icon_set (task);
 		tasks = g_list_append (tasks, task);
 	        layout_tasklist ();
@@ -589,16 +594,22 @@ cb_expose_event (GtkWidget *widget, GdkEventExpose *event)
 
 	temp_tasks = get_visible_tasks ();
 
-	gtk_paint_box (area->style, area->window,
-		       GTK_STATE_NORMAL, GTK_SHADOW_IN,
-		       NULL, area, "button",
-		       0, 0,
-		       area->allocation.width,
-		       area->allocation.height);
-
+	gtk_paint_flat_box (area->style, area->window,
+			    area->state, GTK_SHADOW_NONE,
+			    &event->area, area, "button",
+			    0, 0, -1, -1);
+	
 	while (temp_tasks) {
+		GdkRectangle rect, dest;
 		task = (TasklistTask *)temp_tasks->data;
-		draw_task (task);
+
+		rect.x = task->x;
+		rect.y = task->y;
+		rect.width = task->width;
+		rect.height = task->height;
+
+		if(gdk_rectangle_intersect(&event->area, &rect, &dest))
+			draw_task (task, &dest);
 		temp_tasks = temp_tasks->next;
 	}
 
@@ -809,6 +820,8 @@ main (gint argc, gchar *argv[])
 
 	gdk_rgb_init ();
 
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-tasklist.png");
+
 	gtk_widget_set_default_colormap (gdk_rgb_get_cmap ());
 	gtk_widget_set_default_visual (gdk_rgb_get_visual ());
 
@@ -827,9 +840,7 @@ main (gint argc, gchar *argv[])
 	gtk_widget_show (applet);
 
 	unknown_icon = g_new (TasklistIcon, 1);
-	/* XXX: why do we need to cast unknown_xpm here,
-	   I don't get it -George*/
-	unknown_icon->normal = gdk_pixbuf_new_from_xpm_data ((const gchar **)unknown_xpm);
+	unknown_icon->normal = gdk_pixbuf_new_from_xpm_data (unknown_xpm);
 	unknown_icon->minimized = tasklist_icon_create_minimized_icon (unknown_icon->normal);
 
 	applet_widget_gtk_main ();
