@@ -27,6 +27,7 @@
 #include <zvt/zvtterm.h>
 #include <orb/orbit.h>
 #include <libgnorba/gnorba.h>
+#include <libgnomeui/gnome-window-icon.h>
 
 #include <X11/Xatom.h>
 
@@ -94,6 +95,7 @@ struct terminal_config {
 #ifdef ZVT_BACKGROUND_SCROLL
 	int scroll_background:1; 		/* background will scroll */
 #endif
+	int use_bold         :1;		/* Use bold on bright colours */
 	enum palette_enum color_type; 			/* The color mode */
 	enum color_set_enum color_set;
 	char *font; 				/* Font used by the terminals */
@@ -141,6 +143,7 @@ typedef struct {
 	GtkWidget *scroll_out_checkbox;
 	GtkWidget *swapkeys_checkbox;
 	GtkWidget *login_by_default_checkbox;
+	GtkWidget *use_bold_checkbox;
 	GtkWidget *wordclass_entry;
 	GtkWidget *pixmap_checkbox;
 	GtkWidget *pixmap_file_entry;
@@ -287,7 +290,7 @@ close_all_cmd (void)
  * Keep a copy of the current font name
  */
 static void
-gnome_term_set_font (ZvtTerm *term, char *font_name)
+gnome_term_set_font (ZvtTerm *term, char *font_name, const int use_bold)
 {
 	char *s;
 	GdkFont *font;
@@ -295,7 +298,8 @@ gnome_term_set_font (ZvtTerm *term, char *font_name)
 	font = gdk_font_load (font_name);
 	if (font) {
 #ifdef ZVT_TERM_EMBOLDEN_SUPPORT
-		if (zvt_term_get_capabilities(term) & ZVT_TERM_EMBOLDEN_SUPPORT)
+		if (zvt_term_get_capabilities(term) & ZVT_TERM_EMBOLDEN_SUPPORT &&
+		    use_bold)
 			zvt_term_set_fonts  (term, font, 0);
 		else
 #endif
@@ -484,20 +488,20 @@ load_config (char *class)
 	cfg->font    = gnome_config_get_string ("font=" DEFAULT_FONT);
 	cfg->wordclass  = gnome_config_get_string ("wordclass=-A-Za-z0-9,./?%&#");
 	p = gnome_config_get_string ("scrollpos=right");
-	if (strcasecmp (p, "left") == 0)
+	if (g_strcasecmp (p, "left") == 0)
 		cfg->scrollbar_position = SCROLLBAR_LEFT;
-	else if (strcasecmp (p, "right") == 0)
+	else if (g_strcasecmp (p, "right") == 0)
 		cfg->scrollbar_position = SCROLLBAR_RIGHT;
 	else
 		cfg->scrollbar_position = SCROLLBAR_HIDDEN;
 	p = gnome_config_get_string ("color_scheme=linux");
-	if (strcasecmp (p, "linux") == 0)
+	if (g_strcasecmp (p, "linux") == 0)
 		cfg->color_type = PALETTE_LINUX;
-	else if (strcasecmp (p, "xterm") == 0)
+	else if (g_strcasecmp (p, "xterm") == 0)
 		cfg->color_type = PALETTE_XTERM;
-	else if (strcasecmp (p, "rxvt") == 0)
+	else if (g_strcasecmp (p, "rxvt") == 0)
 		cfg->color_type = PALETTE_RXVT;
-	else if (strcasecmp (p, "custom") == 0)
+	else if (g_strcasecmp (p, "custom") == 0)
 		cfg->color_type = PALETTE_CUSTOM;
 	else
 		cfg->color_type = PALETTE_LINUX;
@@ -509,6 +513,7 @@ load_config (char *class)
 	cfg->swap_keys         = gnome_config_get_bool ("swap_del_and_backspace=0");
 
 	cfg->login_by_default  = gnome_config_get_bool ("login_by_default=0");
+	cfg->use_bold          = gnome_config_get_bool ("use_bold=true");
 
 #ifdef ZVT_BACKGROUND_SCROLL
 	cfg->scroll_background = gnome_config_get_bool ("scroll_background=0");
@@ -533,7 +538,7 @@ load_config (char *class)
 
 	cfg->update_records = ZVT_TERM_DO_UTMP_LOG | ZVT_TERM_DO_WTMP_LOG | ZVT_TERM_DO_LASTLOG;
 
-	if (strcasecmp (fore_color, back_color) == 0)
+	if (g_strcasecmp (fore_color, back_color) == 0)
 		/* don't let them set identical foreground and background colors */
 		cfg->color_set = 0;
 	else {
@@ -578,6 +583,7 @@ gather_changes (ZvtTerm *term)
 	newcfg->scroll_key     = GTK_TOGGLE_BUTTON (prefs->scroll_kbd_checkbox)->active;
 	newcfg->scrollback = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (prefs->scrollback_spin));
 	newcfg->login_by_default = GTK_TOGGLE_BUTTON (prefs->login_by_default_checkbox)->active;
+	newcfg->use_bold = GTK_TOGGLE_BUTTON(prefs->use_bold_checkbox)->active;
 
 	newcfg->transparent = GTK_TOGGLE_BUTTON (prefs->transparent_checkbox)->active;
 	newcfg->shaded = GTK_TOGGLE_BUTTON (prefs->shaded_checkbox)->active;
@@ -654,7 +660,7 @@ apply_changes (ZvtTerm *term, struct terminal_config *newcfg)
 	cfg = terminal_config_dup (newcfg);
 	gtk_object_set_data (GTK_OBJECT (term), "config", cfg);
 
-	gnome_term_set_font (term, cfg->font);
+	gnome_term_set_font (term, cfg->font, cfg->use_bold);
 	zvt_term_set_wordclass (term, (guchar *)cfg->wordclass);
 	zvt_term_set_bell(term, !cfg->bell);
 	zvt_term_set_blink (term, cfg->blink);
@@ -983,12 +989,13 @@ enum {
 	BACKCOLOR_ROW   = 4,
 	CLASS_ROW       = 1,
 	FONT_ROW        = 2,
-	BLINK_ROW       = 3,
-	MENUBAR_ROW     = 4,
-	BELL_ROW        = 5,
-	SWAPKEYS_ROW    = 6,
-	LOGIN_ROW       = 7,
-	WORDCLASS_ROW	= 8,
+	BOLDTOGGLE_ROW  = 3,
+	BLINK_ROW       = 4,
+	MENUBAR_ROW     = 5,
+	BELL_ROW        = 6,
+	SWAPKEYS_ROW    = 7,
+	LOGIN_ROW       = 8,
+	WORDCLASS_ROW	= 9,
 	BACKGROUND_ROW	= 1,
 	PIXMAP_FILE_ROW	= 2,
 	SHADED_ROW      = 4,
@@ -1024,6 +1031,7 @@ save_preferences (GtkWidget *widget, ZvtTerm *term,
 	gnome_config_set_bool   ("blinking", cfg->blink);
 	gnome_config_set_bool   ("swap_del_and_backspace", cfg->swap_keys);
 	gnome_config_set_bool   ("login_by_default", cfg->login_by_default);
+	gnome_config_set_bool   ("use_bold", cfg->use_bold);
 	gnome_config_set_int    ("scrollbacklines", cfg->scrollback);
 	gnome_config_set_int    ("color_set", cfg->color_set);
 	if (cfg->color_type>=4)
@@ -1171,6 +1179,23 @@ preferences_cmd (GtkWidget *widget, ZvtTerm *term)
 	gtk_table_attach (GTK_TABLE (table), prefs->class_box,
 			  2, 3, CLASS_ROW, CLASS_ROW+1, GTK_FILL, 0, GNOME_PAD, GNOME_PAD);
 	
+	/* Toggle the use of bold */
+	
+	prefs->use_bold_checkbox = gtk_check_button_new_with_label (_("Enable bold text"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->use_bold_checkbox),
+	                              cfg->use_bold ? 1 : 0);
+
+#ifdef ZVT_TERM_EMBOLDEN_SUPPORT
+	if (!(zvt_term_get_capabilities(term) & ZVT_TERM_EMBOLDEN_SUPPORT))
+#endif
+		gtk_widget_set_sensitive (prefs->use_bold_checkbox, FALSE);
+
+	gtk_signal_connect (GTK_OBJECT (prefs->use_bold_checkbox), "toggled",
+	                    GTK_SIGNAL_FUNC (prop_changed), prefs);
+	gtk_table_attach (GTK_TABLE(table), prefs->use_bold_checkbox,
+	                  2, 3, BOLDTOGGLE_ROW, BOLDTOGGLE_ROW+1, GTK_FILL, 0,
+	                  GNOME_PAD, GNOME_PAD);
+
 	/* Blinking status */
 	prefs->blink_checkbox = gtk_check_button_new_with_label (_("Blinking cursor"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->blink_checkbox),
@@ -2048,7 +2073,8 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry, i
 		        if ((strncmp (*p, "COLUMNS=", 8) == 0)
 				   || (strncmp (*p, "LINES=", 6) == 0)
 				   || (strncmp(*p, "WINDOWID=", 9) == 0)
-				   || (strncmp (*p, "TERM=", 5) == 0)) {
+			           || (strncmp (*p, "TERM=", 5) == 0)
+				   || (strncmp (*p, "GNOME_DESKTOP_ICON=", 19) == 0)) {
 				/* nothing: do not copy those */
 			} else
 				env_copy [i++] = *p;
@@ -2114,7 +2140,7 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry, i
 				  GTK_OBJECT(term));
 
 	zvt_term_set_scrollback (term, cfg->scrollback);
-	gnome_term_set_font (term, cfg->font);
+	gnome_term_set_font (term, cfg->font, cfg->use_bold);
 	zvt_term_set_wordclass  (term, (guchar *)cfg->wordclass);
 	zvt_term_set_bell  (term, !cfg->bell);
 	zvt_term_set_blink (term, cfg->blink);
@@ -2721,8 +2747,6 @@ main_terminal_program (int argc, char *argv [], char **environ)
 	CORBA_ORB orb;
 	CORBA_Environment ev;
 
-	env = environ;
-	
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 
@@ -2735,22 +2759,23 @@ main_terminal_program (int argc, char *argv [], char **environ)
 
 	/* pre-scan for -x and --execute options */
 	for (i=1;i<argc;i++) {
-		if (!strcmp(argv[i], "-x") || !(strcmp(argv[i], "--execute"))) {
-			int last=i;
+		if (!strcmp (argv [i], "-x") || !(strcmp (argv [i], "--execute"))) {
+			int last = i;
 			i++;
-			if (i==argc) {
+			if (i == argc) {
 				/* no arg!? let popt whinge about usage */
 				break;
 			}
-			initial_command=malloc((argc-i+1)*sizeof(char *));
+			initial_command = malloc ((argc-i+1) * sizeof (char *));
 			j = 0;
-			while (i<argc) {
-				initial_command[j] = argv[i];
-				i++; j++;
+			while (i < argc) {
+				initial_command [j] = argv [i];
+				i++; 
+				j++;
 			}
-			initial_command[j]=NULL;
+			initial_command [j]=NULL;
 			/* 'fool' popt into thinking we have less args */
-			argc=last;
+			argc = last;
 			use_terminal_factory = FALSE;
 			break;
 		}
@@ -2761,30 +2786,35 @@ main_terminal_program (int argc, char *argv [], char **environ)
 						&argc, argv,
 						cb_options, 0, NULL,
 						0, &ev);
+	env = environ;
+
 	if (ev._major != CORBA_NO_EXCEPTION)
-	    exit (5);
+		exit (5);
 
 	CORBA_exception_free (&ev);
 
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-terminal.png");
+
 	/* since -x gets stripped out of the commands, this
 	   will make it override --use-factory */
 	if (use_terminal_factory && initial_command)
 		use_terminal_factory = FALSE;
 
 	if(cmdline_config->user_back_str)
-		gdk_color_parse(cmdline_config->user_back_str,
-				&cmdline_config->palette[17]);
+		gdk_color_parse (cmdline_config->user_back_str,
+				 &cmdline_config->palette[17]);
 	
 	if(cmdline_config->user_fore_str)
-		gdk_color_parse(cmdline_config->user_fore_str,
-				&cmdline_config->palette[16]);
+		gdk_color_parse (cmdline_config->user_fore_str,
+				 &cmdline_config->palette [16]);
 
 	if (cmdline_config->class){
 		class = g_strdup (cmdline_config->class);
 	}
 	else
 	{
-#if 0 /* program_invoation_short_name is broken on non-glibc machines at the moment */	
+#if 0 
+		/* program_invoation_short_name is broken on non-glibc machines at the moment */
 		program = program_invocation_short_name;
 #else
 		program_name = strrchr (argv[0], '/');
