@@ -22,6 +22,7 @@
 #include <config.h>
 #include <string.h>
 #include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 
 #include "gsm-client-list.h"
 #include "gsm-client-row.h"
@@ -365,7 +366,7 @@ main (int argc, char *argv[])
 
   gnome_init_with_popt_table ("session-properties", VERSION, argc, argv, 
 			      options, 0, NULL);
-
+  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-session.png");
   gtk_signal_connect (GTK_OBJECT (gnome_master_client ()), "die",
 		      GTK_SIGNAL_FUNC (gtk_main_quit), NULL);
 
