@@ -45,9 +45,9 @@ static GList *buttons = NULL;
 /*the tiles go here*/
 static struct {
 	GdkPixbuf *tiles_up[LAST_TILE];
-	GdkPixbuf *tiles_up_lc[LAST_TILE];
+	GdkPixbuf *tiles_up_hc[LAST_TILE];
 	GdkPixbuf *tiles_down[LAST_TILE];
-	GdkPixbuf *tiles_down_lc[LAST_TILE];
+	GdkPixbuf *tiles_down_hc[LAST_TILE];
 } tiles = {{NULL}}; /*ansi C trick to make it all 0*/
 
 static int tile_border[LAST_TILE]={0,0,0,0};
@@ -347,9 +347,9 @@ button_widget_destroy(GtkWidget *w, gpointer data)
 	if(button->pixbuf)
 		gdk_pixbuf_unref(button->pixbuf);
 	button->pixbuf = NULL;
-	if(button->pixbuf_lc)
-		gdk_pixbuf_unref(button->pixbuf_lc);
-	button->pixbuf_lc = NULL;
+	if(button->pixbuf_hc)
+		gdk_pixbuf_unref(button->pixbuf_hc);
+	button->pixbuf_hc = NULL;
 	if(button->cache)
 		gdk_pixmap_unref(button->cache);
 	button->cache = NULL;
@@ -364,10 +364,10 @@ loadup_file(char *file)
 {
 	GdkPixbuf *pb = NULL;
 	
-	if(!file)
+	if(!file && !strlen (file))
 		return NULL;
 
-	if(*file!='/') {
+	if(!g_path_is_absolute(file)) {
 		char *f;
 		f = gnome_pixmap_file (file);
 		if(f) {
@@ -379,6 +379,7 @@ loadup_file(char *file)
 	return pb;
 }
 
+#if 0
 /*#define INTENSITY(r, g, b) ((r) * 0.30 + (g) * 0.59 + (b) * 0.11)*/
 #define INTENSITY(r, g, b) (((r)*77 + (g)*150 + (b)*28)>>8)
 
@@ -393,9 +394,10 @@ do_saturate_darken (GdkPixbuf *dest, GdkPixbuf *src,
 	guchar *original_pixels;
 	guchar *pixsrc;
 	guchar *pixdest;
-	guchar intensity;
-	guchar alpha;
-	guchar negalpha;
+	int intensity;
+	int alpha;
+	int negalpha;
+	int val;
 	guchar r,g,b;
 
 	has_alpha = gdk_pixbuf_get_has_alpha (src);
@@ -416,15 +418,59 @@ do_saturate_darken (GdkPixbuf *dest, GdkPixbuf *src,
 			intensity = INTENSITY(r,g,b);
 			negalpha = ((255 - saturation)*darken)>>8;
 			alpha = (saturation*darken)>>8;
-			*(pixdest++) = (negalpha * intensity + alpha * r) >> 8;
-			*(pixdest++) = (negalpha * intensity + alpha * g) >> 8;
-			*(pixdest++) = (negalpha * intensity + alpha * b) >> 8;
+			val = (negalpha * intensity + alpha * r) >> 8;
+			*(pixdest++) = MIN(val, 255);
+			val = (negalpha * intensity + alpha * g) >> 8;
+			*(pixdest++) = MIN(val, 255);
+			val = (negalpha * intensity + alpha * b) >> 8;
+			*(pixdest++) = MIN(val, 255);
 			if (has_alpha)
 				*(pixdest++) = *(pixsrc++);
 		}
 	}
 }
 #undef INTENSITY
+#endif
+
+/* colorshift a pixbuf */
+static void
+do_colorshift (GdkPixbuf *dest, GdkPixbuf *src, int shift)
+{
+	gint i, j;
+	gint width, height, has_alpha, srcrowstride, destrowstride;
+	guchar *target_pixels;
+	guchar *original_pixels;
+	guchar *pixsrc;
+	guchar *pixdest;
+	int val;
+	guchar r,g,b;
+
+	has_alpha = gdk_pixbuf_get_has_alpha (src);
+	width = gdk_pixbuf_get_width (src);
+	height = gdk_pixbuf_get_height (src);
+	srcrowstride = gdk_pixbuf_get_rowstride (src);
+	destrowstride = gdk_pixbuf_get_rowstride (dest);
+	target_pixels = gdk_pixbuf_get_pixels (dest);
+	original_pixels = gdk_pixbuf_get_pixels (src);
+
+	for (i = 0; i < height; i++) {
+		pixdest = target_pixels + i*destrowstride;
+		pixsrc = original_pixels + i*srcrowstride;
+		for (j = 0; j < width; j++) {
+			r = *(pixsrc++);
+			g = *(pixsrc++);
+			b = *(pixsrc++);
+			val = r + shift;
+			*(pixdest++) = CLAMP(val, 0, 255);
+			val = g + shift;
+			*(pixdest++) = CLAMP(val, 0, 255);
+			val = b + shift;
+			*(pixdest++) = CLAMP(val, 0, 255);
+			if (has_alpha)
+				*(pixdest++) = *(pixsrc++);
+		}
+	}
+}
 
 
 
@@ -510,9 +556,11 @@ button_widget_draw(ButtonWidget *button, guchar *rgb, int rowstride)
 	panel = PANEL_WIDGET(widget->parent);
 	size = panel->sz;
 	/*offset for pressed buttons*/
-	off = button->in_button&&button->pressed?SCALE(tile_depth[button->tile]):0;
+	off = (button->in_button && button->pressed) ?
+		SCALE(tile_depth[button->tile]) : 0;
 	/*border to not draw when drawing a tile*/
-	border = tiles_enabled[button->tile]?SCALE(tile_border[button->tile]):0;
+	border = tiles_enabled[button->tile] ?
+		SCALE(tile_border[button->tile]) : 0;
 	 
 	button->size = size;
 	
@@ -521,27 +569,11 @@ button_widget_draw(ButtonWidget *button, guchar *rgb, int rowstride)
 	if(tiles_enabled[button->tile]) {
 		if(button->pressed && button->in_button) {
 			GdkPixbuf *pb;
-			if(global_config.saturate_when_over && !button->in_button) {
-				pb = tiles.tiles_down_lc[button->tile];
-			} else {
-				pb = tiles.tiles_down[button->tile];
-			}
-			if(pb) {
-				double affine[6];
-				make_scale_affine(affine,
-						  gdk_pixbuf_get_width(pb),
-						  gdk_pixbuf_get_height(pb),
-						  size, NULL, NULL);
-				transform_pixbuf(rgb, 0, 0, size, size, rowstride,
-					        pb, affine, ART_FILTER_NEAREST, NULL);
-			}
-		} else if (!global_config.tile_when_over || button->in_button) {
-			GdkPixbuf *pb;
-			if(global_config.saturate_when_over &&
+			if(!global_config.saturate_when_over ||
 			   !button->in_button) {
-				pb = tiles.tiles_up_lc[button->tile];
+				pb = tiles.tiles_down[button->tile];
 			} else {
-				pb = tiles.tiles_up[button->tile];
+				pb = tiles.tiles_down_hc[button->tile];
 			}
 			if(pb) {
 				double affine[6];
@@ -549,18 +581,38 @@ button_widget_draw(ButtonWidget *button, guchar *rgb, int rowstride)
 						  gdk_pixbuf_get_width(pb),
 						  gdk_pixbuf_get_height(pb),
 						  size, NULL, NULL);
-				transform_pixbuf(rgb, 0, 0, size, size, rowstride,
-						pb, affine, ART_FILTER_NEAREST, NULL);
+				transform_pixbuf(rgb, 0, 0, size, size,
+						 rowstride, pb, affine,
+						 ART_FILTER_NEAREST, NULL);
+			}
+		} else if (!global_config.tile_when_over ||
+			   button->in_button) {
+			GdkPixbuf *pb;
+			if(!global_config.saturate_when_over ||
+			   !button->in_button) {
+				pb = tiles.tiles_up[button->tile];
+			} else {
+				pb = tiles.tiles_up_hc[button->tile];
+			}
+			if(pb) {
+				double affine[6];
+				make_scale_affine(affine,
+						  gdk_pixbuf_get_width(pb),
+						  gdk_pixbuf_get_height(pb),
+						  size, NULL, NULL);
+				transform_pixbuf(rgb, 0, 0, size, size,
+						 rowstride, pb, affine,
+						 ART_FILTER_NEAREST, NULL);
 			}
 		}
 	}
 
 	if (pixmaps_enabled[button->tile]) {
 		GdkPixbuf *pb;
-		if(global_config.saturate_when_over && !button->in_button) {
-			pb = button->pixbuf_lc;
-		} else {
+		if(!global_config.saturate_when_over || !button->in_button) {
 			pb = button->pixbuf;
+		} else {
+			pb = button->pixbuf_hc;
 		}
 		if(pb) {
 			double affine[6];
@@ -573,7 +625,7 @@ button_widget_draw(ButtonWidget *button, guchar *rgb, int rowstride)
 			art_affine_translate(transl,
 					     -border+off + (size-w)/2,
 					     -border+off + (size-h)/2);
-			art_affine_multiply(affine,affine,transl);
+			art_affine_multiply(affine, affine, transl);
 
 			transform_pixbuf((rgb+border*rowstride+border*3),
 				         0, 0,
@@ -601,7 +653,8 @@ button_widget_draw_xlib(ButtonWidget *button, GdkPixmap *pixmap)
 	size = button->size;
 
 	/*offset for pressed buttons*/
-	off = button->in_button&&button->pressed?SCALE(tile_depth[button->tile]):0;
+	off = (button->in_button && button->pressed) ?
+		SCALE(tile_depth[button->tile]) : 0;
 	 
 	gc = gdk_gc_new(pixmap);
 	
@@ -622,7 +675,7 @@ button_widget_draw_xlib(ButtonWidget *button, GdkPixmap *pixmap)
 
 		if(!text) text = g_strdup("XXX");
 		
-		font = gdk_font_load("-*-helvetica-medium-r-normal-*-8-*-*-*-*-*-*-*");
+		font = gdk_fontset_load(_("-*-helvetica-medium-r-normal-*-8-*-*-*-*-*-*-*"));
 		if(!font)
 			font = gdk_font_load("fixed");
 		if(!font)
@@ -721,7 +774,7 @@ button_widget_init (ButtonWidget *button)
 	GTK_WIDGET_SET_FLAGS (button, GTK_NO_WINDOW);
 
 	button->pixbuf = NULL;
-	button->pixbuf_lc = NULL;
+	button->pixbuf_hc = NULL;
 	
 	button->tile = 0;
 	button->arrow = 0;
@@ -913,7 +966,7 @@ button_widget_up(ButtonWidget *button)
 }
 
 static GdkPixbuf *
-make_lc_pixbuf(GdkPixbuf *pb)
+make_hc_pixbuf(GdkPixbuf *pb)
 {
 	GdkPixbuf *new;
 	if(!pb)
@@ -924,13 +977,13 @@ make_lc_pixbuf(GdkPixbuf *pb)
 			     gdk_pixbuf_get_bits_per_sample(pb),
 			     gdk_pixbuf_get_width(pb),
 			     gdk_pixbuf_get_height(pb));
-	do_saturate_darken (new, pb, (int)(0.85*255), (int)(0.85*255));
+	do_colorshift(new, pb, 30);
+	/*do_saturate_darken (new, pb, (int)(1.00*255), (int)(1.15*255));*/
 
 	return new;
 }
 
 
-
 GtkWidget*
 button_widget_new(char *filename,
 		  int size,
@@ -947,7 +1000,7 @@ button_widget_new(char *filename,
 	button = BUTTON_WIDGET (gtk_type_new (button_widget_get_type ()));
 	
 	button->pixbuf = loadup_file(filename);
-	button->pixbuf_lc = make_lc_pixbuf(button->pixbuf);
+	button->pixbuf_hc = make_hc_pixbuf(button->pixbuf);
 	button->filename = g_strdup(filename);
 	button->size = size;
 	button->tile = tile;
@@ -966,11 +1019,17 @@ button_widget_set_pixmap(ButtonWidget *button, char *pixmap, int size)
 	g_return_val_if_fail(button != NULL, FALSE);
 	g_return_val_if_fail(IS_BUTTON_WIDGET(button), FALSE);
 
-	if(size<0)
+	if(size < 0)
 		size = PANEL_WIDGET(GTK_WIDGET(button)->parent)->sz;
 	
+	if(button->pixbuf)
+		gdk_pixbuf_unref(button->pixbuf);
+	if(button->pixbuf_hc)
+		gdk_pixbuf_unref(button->pixbuf_hc);
+
 	button->pixbuf = loadup_file(pixmap);
-	button->pixbuf_lc = make_lc_pixbuf(button->pixbuf);
+	button->pixbuf_hc = make_hc_pixbuf(button->pixbuf);
+
 	g_free(button->filename);
 	button->filename = g_strdup(pixmap);
 	button->size = size;
@@ -1032,6 +1091,7 @@ void
 button_widget_load_tile(int tile, char *tile_up, char *tile_down,
 			int border, int depth)
 {
+	GdkPixbuf *pb;
 	GList *list;
 
 	g_return_if_fail(tile >= 0);
@@ -1041,17 +1101,21 @@ button_widget_load_tile(int tile, char *tile_up, char *tile_down,
 
 	if(tiles.tiles_up[tile])
 		gdk_pixbuf_unref(tiles.tiles_up[tile]);
-	if(tiles.tiles_up_lc[tile])
-		gdk_pixbuf_unref(tiles.tiles_up_lc[tile]);
-	tiles.tiles_up[tile] = loadup_file(tile_up);
-	tiles.tiles_up_lc[tile] = make_lc_pixbuf(tiles.tiles_up[tile]);
+	if(tiles.tiles_up_hc[tile])
+		gdk_pixbuf_unref(tiles.tiles_up_hc[tile]);
+
+	pb = loadup_file(tile_up);
+	tiles.tiles_up[tile] = pb;
+	tiles.tiles_up_hc[tile] = make_hc_pixbuf(pb);
 
 	if(tiles.tiles_down[tile])
 		gdk_pixbuf_unref(tiles.tiles_down[tile]);
-	if(tiles.tiles_down_lc[tile])
-		gdk_pixbuf_unref(tiles.tiles_down_lc[tile]);
-	tiles.tiles_down[tile] = loadup_file(tile_down);
-	tiles.tiles_down_lc[tile] = make_lc_pixbuf(tiles.tiles_down[tile]);
+	if(tiles.tiles_down_hc[tile])
+		gdk_pixbuf_unref(tiles.tiles_down_hc[tile]);
+
+	pb = loadup_file(tile_down);
+	tiles.tiles_down[tile] = pb;
+	tiles.tiles_down_hc[tile] = make_hc_pixbuf(pb);
 
 	tile_border[tile] = border;
 	tile_depth[tile] = depth;
