@@ -122,6 +122,7 @@ create_icon_entry(GtkWidget *table,
 		  char *history_id,
 		  int cols, int cole,
 		  char *label,
+		  char *subdir,
 		  char *text,
 		  GtkWidget *w)
 {
@@ -139,6 +140,7 @@ create_icon_entry(GtkWidget *table,
 	gtk_widget_show(wlabel);
 
 	entry = gnome_icon_entry_new(history_id,_("Browse"));
+	gnome_icon_entry_set_pixmap_subdir(GNOME_ICON_ENTRY(entry), subdir);
 	if (text)
 		gnome_icon_entry_set_icon(GNOME_ICON_ENTRY(entry),text);
 
