@@ -260,15 +260,6 @@ panel_orient_change(GtkWidget *widget,
 	panels_to_sync = TRUE;
 }
 
-static void
-floating_pos_change (FloatingPos *pos,
-		     gint x, gint y,
-		     gpointer data)
-{
-	update_config_floating_pos (BASEP_WIDGET (data));
-
-}
-
 static void
 border_edge_change (BorderPos *border,
 		    BorderEdge edge,
@@ -283,30 +274,6 @@ border_edge_change (BorderPos *border,
 	update_config_edge (basep);
 }
 
-static void
-sliding_anchor_change (SlidingPos *pos,
-		       SlidingAnchor anchor,
-		       gpointer data)
-{
-	update_config_anchor (BASEP_WIDGET (data));
-}
-
-static void
-sliding_offset_change (SlidingPos *pos,
-		       gint16 offset,
-		       gpointer data)
-{
-	update_config_offset (BASEP_WIDGET (data));
-}
-
-static void
-aligned_align_change (AlignedPos *pos,
-		      AlignedAlignment align,
-		      gpointer data)
-{
-	update_config_align (BASEP_WIDGET (data));
-}
-
 /*we call this recursively*/
 static void size_change_foreach(GtkWidget *w, gpointer data);
 
@@ -988,7 +955,7 @@ is_this_drop_ok(GtkWidget *widget, GdkDragContext *context, guint *info,
 	g_return_val_if_fail(IS_BASEP_WIDGET (widget) ||
 			     IS_FOOBAR_WIDGET (widget), FALSE);
 
-	if(!(context->actions & GDK_ACTION_COPY))
+	if(!(context->actions & (GDK_ACTION_COPY|GDK_ACTION_MOVE)))
 		return FALSE;
 
 	if (IS_BASEP_WIDGET (widget))
@@ -1010,10 +977,10 @@ is_this_drop_ok(GtkWidget *widget, GdkDragContext *context, guint *info,
 	for(li = context->targets; li; li = li->next) {
 		guint temp_info;
 		if(gtk_target_list_find(panel_target_list, 
-					GPOINTER_TO_INT(li->data),
+					GPOINTER_TO_UINT(li->data),
 					&temp_info)) {
 			if(info) *info = temp_info;
-			if(ret_atom) *ret_atom = GPOINTER_TO_INT(li->data);
+			if(ret_atom) *ret_atom = GPOINTER_TO_UINT(li->data);
 			break;
 		}
 	}
@@ -1052,7 +1019,11 @@ drag_motion_cb(GtkWidget	  *widget,
 	       gint                y,
 	       guint               time)
 {
-	gdk_drag_status (context, GDK_ACTION_COPY, time);
+	/* always prefer copy */
+	if(context->actions & GDK_ACTION_COPY)
+		gdk_drag_status (context, GDK_ACTION_COPY, time);
+	else
+		gdk_drag_status (context, context->suggested_action, time);
 
 	if(!is_this_drop_ok(widget, context, NULL, NULL))
 		return FALSE;
@@ -1158,6 +1129,9 @@ drag_data_recieved_cb (GtkWidget	 *widget,
 	case TARGET_APPLET_INTERNAL:
 		drop_internal_applet(panel, pos, (char *)selection_data->data);
 		break;
+	default:
+		gtk_drag_finish(context,FALSE,FALSE,time);
+		return;
 	}
 
 	gtk_drag_finish(context,TRUE,FALSE,time);
@@ -1207,24 +1181,32 @@ basep_pos_connect_signals (BasePWidget *basep)
 	}
 
 	if (IS_ALIGNED_WIDGET (basep))
-		gtk_signal_connect (GTK_OBJECT (basep->pos),
-				    "align_change",
-				    GTK_SIGNAL_FUNC (aligned_align_change),
-				    basep);
-	else if (IS_FLOATING_WIDGET (basep))
-		gtk_signal_connect (GTK_OBJECT (basep->pos),
-				    "floating_coords_change",
-				    GTK_SIGNAL_FUNC (floating_pos_change),
-				    basep);
-	else if (IS_SLIDING_WIDGET (basep)) {
-		gtk_signal_connect (GTK_OBJECT (basep->pos),
-				    "anchor_change",
-				    GTK_SIGNAL_FUNC (sliding_anchor_change),
-				    basep);
-		gtk_signal_connect (GTK_OBJECT (basep->pos),
-				    "offset_change",
-				    GTK_SIGNAL_FUNC (sliding_offset_change),
-				    basep);
+		gtk_signal_connect_object (GTK_OBJECT (basep->pos),
+					   "align_change",
+					   GTK_SIGNAL_FUNC (update_config_align),
+					   GTK_OBJECT (basep));
+	else if (IS_FLOATING_WIDGET (basep)) {
+		gtk_signal_connect_object (GTK_OBJECT (basep->pos),
+					   "floating_coords_change",
+					   GTK_SIGNAL_FUNC (update_config_floating_pos),
+					   GTK_OBJECT(basep));
+		gtk_signal_connect_object_after (GTK_OBJECT (basep),
+						 "size_allocate",
+						 GTK_SIGNAL_FUNC (update_config_floating_pos_limits),
+						 GTK_OBJECT (basep));
+	} else if (IS_SLIDING_WIDGET (basep)) {
+		gtk_signal_connect_object (GTK_OBJECT (basep->pos),
+					   "anchor_change",
+					   GTK_SIGNAL_FUNC (update_config_anchor),
+					   GTK_OBJECT(basep));
+		gtk_signal_connect_object (GTK_OBJECT (basep->pos),
+					   "offset_change",
+					   GTK_SIGNAL_FUNC (update_config_offset),
+					   GTK_OBJECT (basep));
+		gtk_signal_connect_object_after (GTK_OBJECT (basep),
+						 "size_allocate",
+						 GTK_SIGNAL_FUNC (update_config_offset_limit),
+						 GTK_OBJECT (basep));
 	}
 }
 
